@@ -1,7 +1,10 @@
 import logging
-from typing import Any, Callable, Dict, Iterable, Optional, Union
+from typing import TYPE_CHECKING, Any, Callable, Dict, Optional
 
-from globus_sdk.services.auth import ConfidentialAppAuthClient, OAuthTokenResponse
+from globus_sdk.scopes import MutableScope, _ScopeCollectionType
+
+if TYPE_CHECKING:
+    from globus_sdk.services.auth import ConfidentialAppAuthClient, OAuthTokenResponse
 
 from .renewing import RenewingAuthorizer
 
@@ -36,7 +39,7 @@ class ClientCredentialsAuthorizer(RenewingAuthorizer):
         access tokens that will be used for the Authorization header. These scopes must
         all be for the same resource server, or else the token response will have
         multiple access tokens.
-    :type scopes: str, or iterable of str
+    :type scopes: str, MutableScope, or iterable of str or MutableScope
     :param access_token: Initial Access Token to use, only used if ``expires_at`` is
         also set. Must be requested with the same set of scopes passed to this
         authorizer.
@@ -57,25 +60,26 @@ class ClientCredentialsAuthorizer(RenewingAuthorizer):
 
     def __init__(
         self,
-        confidential_client: ConfidentialAppAuthClient,
-        scopes: Union[str, Iterable[str]],
+        confidential_client: "ConfidentialAppAuthClient",
+        scopes: _ScopeCollectionType,
         *,
         access_token: Optional[str] = None,
         expires_at: Optional[int] = None,
-        on_refresh: Optional[Callable[[OAuthTokenResponse], Any]] = None,
+        on_refresh: Optional[Callable[["OAuthTokenResponse"], Any]] = None,
     ):
-        log.info(
-            "Setting up ClientCredentialsAuthorizer with confidential_client="
-            f"[instance:{id(confidential_client)}] and scopes={scopes}"
-        )
 
         # values for _get_token_data
         self.confidential_client = confidential_client
-        self.scopes = scopes
+        self.scopes = MutableScope.scopes2str(scopes)
+
+        log.info(
+            "Setting up ClientCredentialsAuthorizer with confidential_client="
+            f"[instance:{id(confidential_client)}] and scopes={self.scopes}"
+        )
 
         super().__init__(access_token, expires_at, on_refresh)
 
-    def _get_token_response(self) -> OAuthTokenResponse:
+    def _get_token_response(self) -> "OAuthTokenResponse":
         """
         Make a client credentials grant
         """
@@ -83,7 +87,7 @@ class ClientCredentialsAuthorizer(RenewingAuthorizer):
             requested_scopes=self.scopes
         )
 
-    def _extract_token_data(self, res: OAuthTokenResponse) -> Dict[str, Any]:
+    def _extract_token_data(self, res: "OAuthTokenResponse") -> Dict[str, Any]:
         """
         Get the tokens .by_resource_server,
         Ensure that only one token was gotten, and return that token.
