@@ -11,6 +11,8 @@ from globus_sdk.transport import RequestsTransport
 
 log = logging.getLogger(__name__)
 
+DataParamType = Union[None, str, Dict[str, Any], utils.PayloadWrapper]
+
 
 class BaseClient:
     r"""
@@ -77,11 +79,8 @@ class BaseClient:
         self.transport = self.transport_class(**(transport_params or {}))
         log.debug(f"initialized transport of type {type(self.transport)}")
 
-        if not self.service_name and not base_url:
-            raise ValueError("Either service_name or base_url must be set")
-
         self.base_url = utils.slash_join(
-            config.get_service_url(self.environment, self.service_name)
+            config.get_service_url(self.service_name, environment=self.environment)
             if base_url is None
             else base_url,
             self.base_path,
@@ -140,7 +139,7 @@ class BaseClient:
         path: str,
         *,
         query_params: Optional[Dict[str, Any]] = None,
-        data: Union[None, Dict[str, Any], utils.PayloadWrapper] = None,
+        data: DataParamType = None,
         headers: Optional[Dict[str, str]] = None,
         encoding: Optional[str] = None,
     ) -> GlobusHTTPResponse:
@@ -185,7 +184,7 @@ class BaseClient:
         path: str,
         *,
         query_params: Optional[Dict[str, Any]] = None,
-        data: Union[None, Dict[str, Any], utils.PayloadWrapper] = None,
+        data: DataParamType = None,
         headers: Optional[Dict[str, str]] = None,
         encoding: Optional[str] = None,
     ) -> GlobusHTTPResponse:
@@ -212,7 +211,7 @@ class BaseClient:
         path: str,
         *,
         query_params: Optional[Dict[str, Any]] = None,
-        data: Union[None, Dict[str, Any], utils.PayloadWrapper] = None,
+        data: DataParamType = None,
         headers: Optional[Dict[str, str]] = None,
         encoding: Optional[str] = None,
     ) -> GlobusHTTPResponse:
@@ -240,9 +239,11 @@ class BaseClient:
         path: str,
         *,
         query_params: Optional[Dict[str, Any]] = None,
-        data: Union[None, Dict[str, Any], utils.PayloadWrapper] = None,
+        data: DataParamType = None,
         headers: Optional[Dict[str, str]] = None,
         encoding: Optional[str] = None,
+        allow_redirects: bool = True,
+        stream: bool = False,
     ) -> GlobusHTTPResponse:
         """
         Send an HTTP request
@@ -262,9 +263,18 @@ class BaseClient:
             registered with the transport. By default, strings get "text" behavior and
             all other objects get "json".
         :type encoding: str
+        :param allow_redirects: Follow Location headers on redirect response
+            automatically. Defaults to ``True``
+        :type allow_redirects: bool
+        :param stream: Do not immediately download the response content. Defaults to
+            ``False``
+        :type stream: bool
 
         :return: :class:`GlobusHTTPResponse \
         <globus_sdk.response.GlobusHTTPResponse>` object
+
+        :raises GlobusAPIError: a `GlobusAPIError` will be raised if the response to the
+            request is received and has a status code in the 4xx or 5xx categories
         """
         # prepare data...
         # copy headers if present
@@ -287,6 +297,8 @@ class BaseClient:
             headers=rheaders,
             encoding=encoding,
             authorizer=self.authorizer,
+            allow_redirects=allow_redirects,
+            stream=stream,
         )
         log.debug("request made to URL: %s", r.url)
 
