@@ -2,6 +2,8 @@ import logging
 import os
 from typing import Any, Dict, List, Optional, Type, cast
 
+from .env_vars import get_environment_name
+
 log = logging.getLogger(__name__)
 # the format string for a service URL pulled out of the environment
 # these are handled with uppercased service names, e.g.
@@ -12,7 +14,8 @@ _SERVICE_URL_VAR_FORMAT = "GLOBUS_SDK_SERVICE_URL_{}"
 class EnvConfig:
     envname: str
     domain: str
-    no_dotapi: List[str] = ["auth"]
+    no_dotapi: List[str] = ["app", "auth"]
+    automate_services: List[str] = ["actions", "flows", "timer"]
 
     # this same dict is inherited (and therefore shared!) by all subclasses
     _registry: Dict[str, Type["EnvConfig"]] = {}
@@ -28,7 +31,7 @@ class EnvConfig:
     #
     # and retrieve it with get_config_by_name("beta")
     def __init_subclass__(cls, **kwargs: Any):
-        super().__init_subclass__(**kwargs)  # type: ignore
+        super().__init_subclass__(**kwargs)
         cls._registry[cls.envname] = cls
 
     @classmethod
@@ -43,15 +46,30 @@ class EnvConfig:
         # check `no_dotapi` for services which don't have `.api` in their names
         if service in cls.no_dotapi:
             return f"https://{service}.{cls.domain}/"
+        if service in cls.automate_services:
+            return f"https://{cls.envname}.{service}.automate.globus.org/"
         return f"https://{service}.api.{cls.domain}/"
 
     @classmethod
-    def get_by_name(cls, envname: str) -> Optional[Type["EnvConfig"]]:
-        return cls._registry.get(envname)
+    def get_by_name(cls, env: str) -> Optional[Type["EnvConfig"]]:
+        return cls._registry.get(env)
 
 
-def get_service_url(environment: str, service: str) -> str:
+def get_service_url(service: str, environment: Optional[str] = None) -> str:
+    """
+    Return the base URL for the given service in this environment. For example:
+
+    >>> from globus_sdk.config import get_service_url
+    >>> get_service_url("auth", environment="preview")
+    'https://auth.preview.globus.org/'
+    >>> get_service_url("search", environment="production")
+    'https://search.api.globus.org/'
+
+    If no ``environment`` is specified, this will use the ``GLOBUS_SDK_ENVIRONMENT``
+    environment variable.
+    """
     log.debug(f'Service URL Lookup for "{service}" under env "{environment}"')
+    environment = environment or get_environment_name()
     # check for an environment variable of the form
     #   GLOBUS_SDK_SERVICE_URL_*
     # and use it ahead of any env config if set
@@ -68,6 +86,17 @@ def get_service_url(environment: str, service: str) -> str:
     return url
 
 
+def get_webapp_url(environment: Optional[str] = None) -> str:
+    """
+    Return the URL to access the Globus web app in the given environment. For example:
+
+    >>> get_webapp_url("preview")
+    'https://app.preview.globus.org/'
+    """
+    environment = environment or get_environment_name()
+    return get_service_url("app", environment=environment)
+
+
 #
 # public environments
 #
@@ -77,6 +106,8 @@ class ProductionEnvConfig(EnvConfig):
     envname = "production"
     domain = "globus.org"
     nexus_url = "https://nexus.api.globusonline.org/"
+    timer_url = "https://timer.automate.globus.org/"
+    actions_url = "https://actions.automate.globus.org/"
 
 
 class PreviewEnvConfig(EnvConfig):
@@ -92,5 +123,8 @@ for envname in ["sandbox", "integration", "test", "staging"]:
     type(
         f"{envname.title()}EnvConfig",
         (EnvConfig,),
-        {"envname": envname, "domain": f"{envname}.globuscs.info"},
+        {
+            "envname": envname,
+            "domain": f"{envname}.globuscs.info",
+        },
     )
