@@ -1,3 +1,4 @@
+import collections.abc
 import json
 import logging
 from typing import (
@@ -5,6 +6,7 @@ from typing import (
     Any,
     ClassVar,
     Iterator,
+    List,
     Mapping,
     Optional,
     Union,
@@ -31,7 +33,8 @@ class GlobusHTTPResponse:
     ``GlobusHTTPResponse`` object implements the immutable mapping protocol for
     dict-style access. This is just an alias for access to the underlying data.
 
-    If ``data`` is not a dictionary, item access will raise ``TypeError``.
+    If the response data is not a dictionary or list, item access will raise
+    ``TypeError``.
 
     >>> print("Response ID": r["id"]) # alias for r.data["id"]
 
@@ -93,6 +96,17 @@ class GlobusHTTPResponse:
         """The HTTP response status, as an integer."""
         return self._raw_response.status_code
 
+    @property
+    def http_reason(self) -> str:
+        """
+        The HTTP reason string from the response.
+
+        This is the part of the status line after the status code, and typically is a
+        string description of the status. If the status line is
+        ``HTTP/1.1 200 OK``, then this is the string ``"OK"``.
+        """
+        return self._raw_response.reason
+
     @property
     def headers(self) -> Mapping[str, str]:
         """
@@ -137,14 +151,14 @@ class GlobusHTTPResponse:
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}({self.text})"
 
-    def __getitem__(self, key: str) -> Any:
+    def __getitem__(self, key: Union[str, int, slice]) -> Any:
         # force evaluation of the data property outside of the upcoming
         # try-catch so that we don't accidentally catch TypeErrors thrown
         # during the getter function itself
         data = self.data
         try:
             return data[key]
-        except TypeError:
+        except TypeError as err:
             log.error(
                 f"Can't index into responses with underlying data of type {type(data)}"
             )
@@ -154,7 +168,9 @@ class GlobusHTTPResponse:
             #
             # "type" is ambiguous, but we don't know if it's the fault of the
             # class at large, or just a particular call's `data` property
-            raise ValueError("This type of response data does not support indexing.")
+            raise ValueError(
+                "This type of response data does not support indexing."
+            ) from err
 
     def __contains__(self, item: Any) -> bool:
         """
@@ -164,6 +180,12 @@ class GlobusHTTPResponse:
             return False
         return item in self.data
 
+    def __bool__(self) -> bool:
+        """
+        ``bool(response)`` is an alias for ``bool(response.data)``
+        """
+        return bool(self.data)
+
 
 class IterableResponse(GlobusHTTPResponse):
     """This response class adds an __iter__ method on an 'iter_key' variable.
@@ -190,3 +212,21 @@ class IterableResponse(GlobusHTTPResponse):
 
     def __iter__(self) -> Iterator[Mapping[Any, Any]]:
         return iter(cast(Mapping[Any, Any], self)[self.iter_key])
+
+
+class ArrayResponse(GlobusHTTPResponse):
+    """This response class adds an ``__iter__`` method which assumes that the top-level
+    data of the response is a JSON array."""
+
+    def __iter__(self) -> Iterator[Any]:
+        return iter(cast(List[Any], self.data))
+
+    def __len__(self) -> int:
+        """
+        ``len(response)`` is an alias for ``len(response.data)``
+        """
+        if not isinstance(self.data, collections.abc.Sequence):
+            raise TypeError(
+                f"Cannot take len() on data when type is '{type(self.data).__name__}'"
+            )
+        return len(self.data)
