@@ -2,37 +2,27 @@ import collections.abc
 import json
 import logging
 import sys
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    Iterable,
-    Optional,
-    Type,
-    TypeVar,
-    Union,
-    cast,
-    overload,
-)
+from typing import Any, Dict, Iterable, Optional, Type, TypeVar, Union, cast, overload
 
 import jwt
 from cryptography.hazmat.primitives.asymmetric.rsa import RSAPublicKey
 
-if TYPE_CHECKING:
-    if sys.version_info >= (3, 8):
-        from typing import Literal
-    else:
-        from typing_extensions import Literal
+if sys.version_info >= (3, 8):
+    # pylint can't handle quoted annotations yet:
+    # https://github.com/PyCQA/pylint/issues/3299
+    from typing import Literal  # pylint: disable=unused-import
+else:
+    from typing_extensions import Literal
 
 from globus_sdk import client, exc, utils
+from globus_sdk._types import IntLike, UUIDLike
 from globus_sdk.authorizers import NullAuthorizer
 from globus_sdk.response import GlobusHTTPResponse
 from globus_sdk.scopes import AuthScopes
-from globus_sdk.types import IntLike, UUIDLike
 
 from ..errors import AuthAPIError
 from ..flow_managers import GlobusOAuthFlowManager
-from ..response import OAuthTokenResponse
+from ..response import GetIdentitiesResponse, OAuthTokenResponse
 
 log = logging.getLogger(__name__)
 
@@ -110,19 +100,32 @@ class AuthClient(client.BaseClient):
 
         Available with any authentication/client type.
 
+        :param usernames: A username or list of usernames to lookup. Mutually exclusive
+            with ``ids``
+        :type usernames: str or iterable of str, optional
+        :param ids: An identity ID or list of IDs to lookup. Mutually exclusive
+            with ``usernames``
+        :type ids: str, UUID, or iterable of str or UUID, optional
+        :param provision: Create identities if they do not exist, allowing clients to
+            get username-to-identity mappings prior to the identity being used
+        :type provision: bool
+        :param query_params: Any additional parameters to be passed through
+            as query params.
+        :type query_params: dict, optional
+
         **Examples**
 
         >>> ac = globus_sdk.AuthClient(...)
         >>> # by IDs
         >>> r = ac.get_identities(ids="46bd0f56-e24f-11e5-a510-131bef46955c")
         >>> r.data
-        {u'identities': [{u'email': None,
-           u'id': u'46bd0f56-e24f-11e5-a510-131bef46955c',
-           u'identity_provider': u'7daddf46-70c5-45ee-9f0f-7244fe7c8707',
-           u'name': None,
-           u'organization': None,
-           u'status': u'unused',
-           u'username': u'globus@globus.org'}]}
+        {'identities': [{'email': None,
+           'id': '46bd0f56-e24f-11e5-a510-131bef46955c',
+           'identity_provider': '7daddf46-70c5-45ee-9f0f-7244fe7c8707',
+           'name': None,
+           'organization': None,
+           'status': 'unused',
+           'username': 'globus@globus.org'}]}
         >>> ac.get_identities(
         >>>     ids=",".join(
         >>>         ("46bd0f56-e24f-11e5-a510-131bef46955c",
@@ -144,6 +147,13 @@ class AuthClient(client.BaseClient):
         >>>     ids=["46bd0f56-e24f-11e5-a510-131bef46955c",
         >>>          "168edc3d-c6ba-478c-9cf8-541ff5ebdc1c"])
         ...
+
+        The result itself is iterable, so you can use it like so:
+
+        >>> for identity in ac.get_identities(
+        >>>     usernames=['globus@globus.org', 'auth@globus.org']
+        >>> ):
+        >>>     print(identity["id"])
         """
 
         def _convert_listarg(
@@ -178,7 +188,9 @@ class AuthClient(client.BaseClient):
                 "identities set! Expected to result in errors"
             )
 
-        return self.get("/v2/api/identities", query_params=query_params)
+        return GetIdentitiesResponse(
+            self.get("/v2/api/identities", query_params=query_params)
+        )
 
     def oauth2_get_authorize_url(
         self, *, query_params: Optional[Dict[str, Any]] = None
@@ -424,6 +436,11 @@ class AuthClient(client.BaseClient):
             requires a specialize response class to handle the dramatically different
             format of the Dependent Token Grant response
         :type response_class: class, optional
+        :param form_data: The main body of the request
+        :type form_data: dict or `utils.PayloadWrapper`
+        :param body_params: Any additional parameters to be passed through
+            as body parameters.
+        :type body_params: dict, optional
         :rtype: ``response_class``
         """
         log.info("Fetching new token from Globus Auth")
