@@ -1,15 +1,16 @@
 import logging
 import time
 import uuid
-from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
+from typing import Any, Dict, Iterable, List, Optional, Tuple, Type, Union
 
 from globus_sdk import client, exc, paging, response, utils
+from globus_sdk._types import DateLike, IntLike, UUIDLike
 from globus_sdk.scopes import TransferScopes
-from globus_sdk.types import DateLike, IntLike, UUIDLike
 
 from .data import DeleteData, TransferData
 from .errors import TransferAPIError
 from .response import ActivationRequirementsResponse, IterableTransferResponse
+from .transport import TransferRequestsTransport
 
 log = logging.getLogger(__name__)
 
@@ -97,6 +98,7 @@ class TransferClient(client.BaseClient):
     """
     service_name = "transfer"
     base_path = "/v0.10/"
+    transport_class: Type[TransferRequestsTransport] = TransferRequestsTransport
     error_class = TransferAPIError
     scopes = TransferScopes
 
@@ -433,6 +435,8 @@ class TransferClient(client.BaseClient):
             fetched from :meth:`~endpoint_get_activation_requirements`. Only the fields
             for the activation type being used need to be filled in.
         :type requirements_data: dict
+        :param requirements_data: An optional body for the request
+        :type requirements_data: dict, optional
         :param query_params: Any additional parameters will be passed through
             as query params.
         :type query_params: dict, optional
@@ -543,9 +547,9 @@ class TransferClient(client.BaseClient):
         :type max_results: int, optional
         :param next_token: token used for paging
         :type next_token: str, optional
-        :param query_params: Any additional parameters will be passed through
+        :param query_params: Any additional parameters to be passed through
             as query params.
-        :type query_param: dict, optional
+        :type query_params: dict, optional
 
         Get a list of all shared endpoints on a given host endpoint.
         """
@@ -606,6 +610,9 @@ class TransferClient(client.BaseClient):
 
         :param endpoint_id: The endpoint whose servers are being listed
         :type endpoint_id: str or UUID
+        :param query_params: Any additional parameters to be passed through
+            as query params.
+        :type query_params: dict, optional
         """
         log.info(f"TransferClient.endpoint_server_list({endpoint_id}, ...)")
         return IterableTransferResponse(
@@ -715,6 +722,9 @@ class TransferClient(client.BaseClient):
 
         :param endpoint_id: The endpoint whose roles are being listed
         :type endpoint_id: str or UUID
+        :param query_params: Any additional parameters to be passed through
+            as query params.
+        :type query_params: dict, optional
         """
         log.info(f"TransferClient.endpoint_role_list({endpoint_id}, ...)")
         return IterableTransferResponse(
@@ -998,6 +1008,7 @@ class TransferClient(client.BaseClient):
         show_hidden: Optional[bool] = None,
         orderby: Optional[Union[str, List[str]]] = None,
         # note: filter is a soft keyword in python, so using this name is okay
+        # pylint: disable=redefined-builtin
         filter: Union[str, TransferFilterDict, None] = None,
         query_params: Optional[Dict[str, Any]] = None,
     ) -> IterableTransferResponse:
@@ -1296,6 +1307,7 @@ class TransferClient(client.BaseClient):
         *,
         limit: Optional[int] = None,
         offset: Optional[int] = None,
+        # pylint: disable=redefined-builtin
         filter: Union[str, TransferFilterDict, None] = None,
         query_params: Optional[Dict[str, Any]] = None,
     ) -> IterableTransferResponse:
@@ -1583,9 +1595,15 @@ class TransferClient(client.BaseClient):
     @utils.doc_api_method(
         "Get Task Successful Transfer", "transfer/task/#get_task_successful_transfers"
     )
-    @paging.has_paginator(paging.MarkerPaginator, items_key="DATA")
+    @paging.has_paginator(
+        paging.NullableMarkerPaginator, items_key="DATA", marker_key="next_marker"
+    )
     def task_successful_transfers(
-        self, task_id: UUIDLike, *, query_params: Optional[Dict[str, Any]] = None
+        self,
+        task_id: UUIDLike,
+        *,
+        marker: Optional[str] = None,
+        query_params: Optional[Dict[str, Any]] = None,
     ) -> IterableTransferResponse:
         """
         ``GET /task/<task_id>/successful_transfers``
@@ -1601,6 +1619,8 @@ class TransferClient(client.BaseClient):
 
         :param task_id: The ID of the task to inspect
         :type task_id: str or UUID
+        :param marker: A marker for pagination
+        :type marker: str
         :param query_params: Additional passthrough query parameters
         :type query_params: dict, optional
 
@@ -1615,6 +1635,10 @@ class TransferClient(client.BaseClient):
         >>>         info["source_path"], info["destination_path"]))
         """
         log.info(f"TransferClient.task_successful_transfers({task_id}, ...)")
+        if query_params is None:
+            query_params = {}
+        if marker is not None:
+            query_params["marker"] = marker
         return IterableTransferResponse(
             self.get(f"task/{task_id}/successful_transfers", query_params=query_params)
         )
@@ -1622,9 +1646,15 @@ class TransferClient(client.BaseClient):
     @utils.doc_api_method(
         "Get Task Skipped Errors", "transfer/task/#get_task_skipped_errors"
     )
-    @paging.has_paginator(paging.MarkerPaginator, items_key="DATA")
+    @paging.has_paginator(
+        paging.NullableMarkerPaginator, items_key="DATA", marker_key="next_marker"
+    )
     def task_skipped_errors(
-        self, task_id: UUIDLike, *, query_params: Optional[Dict[str, Any]] = None
+        self,
+        task_id: UUIDLike,
+        *,
+        marker: Optional[str] = None,
+        query_params: Optional[Dict[str, Any]] = None,
     ) -> IterableTransferResponse:
         """
         ``GET /task/<task_id>/skipped_errors``
@@ -1634,6 +1664,8 @@ class TransferClient(client.BaseClient):
 
         :param task_id: The ID of the task to inspect
         :type task_id: str or UUID
+        :param marker: A marker for pagination
+        :type marker: str
         :param query_params: Additional passthrough query parameters
         :type query_params: dict, optional
 
@@ -1648,6 +1680,10 @@ class TransferClient(client.BaseClient):
         >>>         info["error_code"], info["source_path"]))
         """
         log.info("TransferClient.task_skipped_errors(%s, ...)", task_id)
+        if query_params is None:
+            query_params = {}
+        if marker is not None:
+            query_params["marker"] = marker
         return IterableTransferResponse(
             self.get(f"task/{task_id}/skipped_errors", query_params=query_params)
         )
@@ -1999,9 +2035,15 @@ class TransferClient(client.BaseClient):
         "Get task successful transfers as admin",
         "transfer/advanced_endpoint_management/#get_task_successful_transfers_as_admin",
     )
-    @paging.has_paginator(paging.MarkerPaginator, items_key="DATA")
+    @paging.has_paginator(
+        paging.NullableMarkerPaginator, items_key="DATA", marker_key="next_marker"
+    )
     def endpoint_manager_task_successful_transfers(
-        self, task_id: UUIDLike, *, query_params: Optional[Dict[str, Any]] = None
+        self,
+        task_id: UUIDLike,
+        *,
+        marker: Optional[str] = None,
+        query_params: Optional[Dict[str, Any]] = None,
     ) -> IterableTransferResponse:
         """
         ``GET /endpoint_manager/task/<task_id>/successful_transfers``
@@ -2010,6 +2052,8 @@ class TransferClient(client.BaseClient):
 
         :param task_id: The ID of the task to inspect
         :type task_id: str or UUID
+        :param marker: A marker for pagination
+        :type marker: str
         :param query_params: Additional passthrough query parameters
         :type query_params: dict, optional
         """
@@ -2017,6 +2061,10 @@ class TransferClient(client.BaseClient):
             "TransferClient.endpoint_manager_task_successful_transfers(%s, ...)",
             task_id,
         )
+        if query_params is None:
+            query_params = {}
+        if marker is not None:
+            query_params["marker"] = marker
         return IterableTransferResponse(
             self.get(
                 "endpoint_manager/task/{task_id}/successful_transfers",
@@ -2028,8 +2076,15 @@ class TransferClient(client.BaseClient):
         "Get task skipped errors as admin",
         "transfer/advanced_endpoint_management/#get_task_skipped_errors_as_admin",
     )
+    @paging.has_paginator(
+        paging.NullableMarkerPaginator, items_key="DATA", marker_key="next_marker"
+    )
     def endpoint_manager_task_skipped_errors(
-        self, task_id: UUIDLike, *, query_params: Optional[Dict[str, Any]] = None
+        self,
+        task_id: UUIDLike,
+        *,
+        marker: Optional[str] = None,
+        query_params: Optional[Dict[str, Any]] = None,
     ) -> IterableTransferResponse:
         """
         ``GET /endpoint_manager/task/<task_id>/skipped_errors``
@@ -2038,10 +2093,16 @@ class TransferClient(client.BaseClient):
 
         :param task_id: The ID of the task to inspect
         :type task_id: str
+        :param marker: A marker for pagination
+        :type marker: str
         :param query_params: Additional passthrough query parameters
         :type query_params: dict, optional
         """
         log.info(f"TransferClient.endpoint_manager_task_skipped_errors({task_id}, ...)")
+        if query_params is None:
+            query_params = {}
+        if marker is not None:
+            query_params["marker"] = marker
         return IterableTransferResponse(
             self.get(
                 f"endpoint_manager/task/{task_id}/skipped_errors",
